poppy-core
===========

[![pipeline status](https://gitlab.obspm.fr/POPPY/POPPyCore/badges/develop/pipeline.svg)](https://gitlab.obspm.fr/POPPY/POPPyCore/pipelines)

This directory contains the source code of the POPPY framework core.

## Quickstart

To install package using [pip](https://pypi.org/project/pip-tools/):

```
pip install poppy-core --extra-index-url https://__token__:<your_personal_token>@gitlab.obspm.fr/api/v4/projects/2052/packages/pypi/simple --trusted-host gitlab.obspm.fr
```

To install package from source files:

```
git clone https://gitlab.obspm.fr/POPPY/POPPyCore.git poppy-core
```

Then install using [pip](https://pypi.org/project/pip-tools/):

```
cd poppy-core
pip install .
```

or using [poetry](https://python-poetry.org/):

```
cd poppy-core
pip install poetry
poetry install
```

## User guide

See "POPPY User Manual" for more details.

## License

POPPY is under CeCILL license.

## Acknowledgement

POPPY is project developed by the RPW Operations Centre (ROC) team based at LESIA (Meudon, France).
The ROC is funded by the Centre National d'Etudes Spatiale (CNES) in the framework of the European Space Agency (ESA) Solar Orbiter mission.

## Authors

xavier.bonnin@obspm.fr (project manager)


Has also contributed in the past: Sonny Lion, Gregoire Duvauchelle, Manuel Duarte
